from pywebio import start_server, config
from pywebio.output import *
from pywebio.input import *
from pytube import *
from instaloader import *



def app():
    link = input(placeholder="URL tashlang")
    toast("Yuklanmoqda...")
    try:
        youtube = YouTube(link)
        youtube.streams.get_highest_resolution().download(output_path="Dowloaded")
        toast("Muvaffaiqiyatli yuklandi!")
    except:
        toast("Xatolik Yuz berdi!")

    

    profile_name = input ( "Instagram nomini yozing: " )
    toast( "Yuklanmoqda..." )
    instaloader . Instaloader ( ) . download_profile ( profile_name , profile_pic_only = False )
    toast( "Muvaffaqqiyatli yuklandi!" )



start_server(app, debug=True)



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['yuklovchi']
install_requires = \
['instaloader>=4.9.5,<5.0.0', 'pytube>=12.1.0,<13.0.0', 'pywebio>=1.6.3,<2.0.0']

setup_kwargs = {
    'name': 'yuklovchi',
    'version': '0.0.1',
    'description': 'Bu kutobxona yordamida YouTubedan va Instagramdan yuklashingiz mumkin.',
    'long_description': '',
    'author': 'Nodir Bahodirov',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
